==> haskell-hls-gadt-plugin-1.0.2.0-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-gadt-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-gadt-plugin
version:              1.0.2.0
visibility:           public
id:                   hls-gadt-plugin-1.0.2.0-Kz5PYbtSXwJHTmrobHxmJV
key:                  hls-gadt-plugin-1.0.2.0-Kz5PYbtSXwJHTmrobHxmJV
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Convert to GADT syntax plugin
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-gadt-plugin#readme>

category:             Development
abi:                  e25eefb3721f6e01055c91b6f38b403c
exposed:              True
exposed-modules:      Ide.Plugin.GADT
hidden-modules:       Ide.Plugin.GHC
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-gadt-plugin-1.0.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-gadt-plugin-1.0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-gadt-plugin
hs-libraries:         HShls-gadt-plugin-1.0.2.0-Kz5PYbtSXwJHTmrobHxmJV
depends:
    aeson-2.1.2.1-7IgTEIjsesxDBKStPrg8Ee base-4.16.4.0
    containers-0.6.5.1 extra-1.7.16-CDnJ4IIZiy49QmNU3HquQ1 ghc-9.2.8
    ghc-boot-th-9.2.8 ghc-exactprint-1.5.0-EhuuAzC8u9QHyfNeVkJASW
    ghcide-1.10.0.0-LUOZfaZsPo92GAjJrHasb
    hls-plugin-api-1.6.0.0-IlaR5sSrdwK8yu9HE27Hij
    hls-refactor-plugin-1.2.0.0-2vhEE3owSJd2JaPRlmxXhF
    lens-5.2.3-3BG1BTsYajWH51jWMi4vYO
    lsp-1.6.0.0-DT4gnHhljAEFkxKkAe5FzR mtl-2.2.2 text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-4c1XIGAoQE4JZSLkR4PXOi

haddock-interfaces:
    /usr/share/doc/haskell-hls-gadt-plugin/html/hls-gadt-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-gadt-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-gadt-plugin-1.0.2.0-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-gadt-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-gadt-plugin
version:              1.0.2.0
visibility:           public
id:                   hls-gadt-plugin-1.0.2.0-5mLUlL9A2CjAwQrYdJqrS
key:                  hls-gadt-plugin-1.0.2.0-5mLUlL9A2CjAwQrYdJqrS
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Convert to GADT syntax plugin
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-gadt-plugin#readme>

category:             Development
abi:                  a02238368046eadb4e2694d6808f58ef
exposed:              True
exposed-modules:      Ide.Plugin.GADT
hidden-modules:       Ide.Plugin.GHC
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hls-gadt-plugin-1.0.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hls-gadt-plugin-1.0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-gadt-plugin
hs-libraries:         HShls-gadt-plugin-1.0.2.0-5mLUlL9A2CjAwQrYdJqrS
depends:
    aeson-2.1.2.1-HbpdIbO6AMR9AnrzgnqgHA base-4.16.4.0
    containers-0.6.5.1 extra-1.7.16-LvCisaJe0r84H5u45TnjVU ghc-9.2.8
    ghc-boot-th-9.2.8 ghc-exactprint-1.5.0-3IcvrrFMxq3Dh4zYrY1pmZ
    ghcide-1.10.0.0-JAYr5u0LqJB5oiYVxdFyXE
    hls-plugin-api-1.6.0.0-G7p1SsZyfJjFQU1Rh4InUp
    hls-refactor-plugin-1.2.0.0-HFuEW4MnAl6KPJZLBFu7r4
    lens-5.2.3-8lYAGRbsVBB5Dn410nzJey
    lsp-1.6.0.0-K5sMJCq0XCfJihpkwmS2i0 mtl-2.2.2 text-1.2.5.0
    transformers-0.5.6.2
    unordered-containers-0.2.20-FlJ58vN39MpAJvDCdrVy2C

haddock-interfaces:
    /usr/share/doc/haskell-hls-gadt-plugin/html/hls-gadt-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-gadt-plugin/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
